aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors
diff options
context:
space:
mode:
authorMichael Mann <mmann78@netscape.net>2016-11-02 21:01:26 -0400
committerMichael Mann <mmann78@netscape.net>2016-11-03 02:31:08 +0000
commita01fac7106106b4c7d5a426f74415dbca7169ff1 (patch)
treeae6a5639a8aa4fb215c9f11fae2972f412ee59e6 /epan/dissectors
parent79b4a05bef50d8413bc6422372ee8b341156c26c (diff)
Fix lintian found spelling error "occured" -> "occurred"
Change-Id: I6010669b880b772ba4a22f13ba03fe48b438e8b7 Reviewed-on: https://code.wireshark.org/review/18644 Reviewed-by: Michael Mann <mmann78@netscape.net>
Diffstat (limited to 'epan/dissectors')
-rw-r--r--epan/dissectors/packet-netflow.c4
-rw-r--r--epan/dissectors/packet-quic.c4
-rw-r--r--epan/dissectors/packet-s7comm.c4
3 files changed, 6 insertions, 6 deletions
diff --git a/epan/dissectors/packet-netflow.c b/epan/dissectors/packet-netflow.c
index 126bd90604..33072938e2 100644
--- a/epan/dissectors/packet-netflow.c
+++ b/epan/dissectors/packet-netflow.c
@@ -11757,13 +11757,13 @@ proto_register_netflow(void)
{&hf_pie_netscaler_icaclientsidertocount,
{"ICA Clientside RTO Count", "cflow.pie.netscaler.ica-clientside-rto-count",
FT_UINT16, BASE_DEC, NULL, 0x0,
- "ICA Clientside retrans timeout occured Count", HFILL}
+ "ICA Clientside retrans timeout occurred Count", HFILL}
},
/* netscaler, 5951 / 264 */
{&hf_pie_netscaler_icaserversidertocount,
{"ICA Serverside RTO Count", "cflow.pie.netscaler.ica-serverside-rto-count",
FT_UINT16, BASE_DEC, NULL, 0x0,
- "ICA Serverside retrans timeout occured Count", HFILL}
+ "ICA Serverside retrans timeout occurred Count", HFILL}
},
/* netscaler, 5951 / 265 */
{&hf_pie_netscaler_ical7clientlatency,
diff --git a/epan/dissectors/packet-s7comm.c b/epan/dissectors/packet-s7comm.c
index e76ded5cac..703d70d8df 100644
--- a/epan/dissectors/packet-s7comm.c
+++ b/epan/dissectors/packet-s7comm.c
@@ -3408,7 +3408,7 @@ s7comm_decode_plc_controls_updownload(tvbuff_t *tvb,
}
break;
}
- /* if an error occured show in info column */
+ /* if an error occurred show in info column */
if (errorcode > 0) {
col_append_fstr(pinfo->cinfo, COL_INFO, " -> Errorcode:[0x%04x]", errorcode);
}
@@ -5833,7 +5833,7 @@ proto_register_s7comm (void)
"More data of the block/file can be retrieved with another request", HFILL }},
{ &hf_s7comm_data_blockcontrol_functionstatus_error,
{ "Error", "s7comm.param.blockcontrol.functionstatus.error", FT_BOOLEAN, 8, NULL, 0x02,
- "An error occured", HFILL }},
+ "An error occurred", HFILL }},
/* NC programming functions */
{ &hf_s7comm_data_ncprg_unackcount,
diff --git a/epan/dissectors/packet-quic.c b/epan/dissectors/packet-quic.c
index d3b4f35cfe..1d7fa76b72 100644
--- a/epan/dissectors/packet-quic.c
+++ b/epan/dissectors/packet-quic.c
@@ -631,7 +631,7 @@ enum QuicErrorCode {
/* A crypto message was received that contained a parameter with too few
values. */
QUIC_CRYPTO_MESSAGE_INDEX_NOT_FOUND = 37,
/* An internal error occured in crypto processing. */
QUIC_CRYPTO_INTERNAL_ERROR = 38,
/* A crypto handshake message specified an unsupported version. */
QUIC_CRYPTO_VERSION_NOT_SUPPORTED = 39,
@@ -731,7 +731,7 @@ static const value_string error_code_vals[] = {
{ QUIC_CRYPTO_MESSAGE_PARAMETER_NOT_FOUND, "A crypto message was received with a mandatory parameter missing" },
{ QUIC_CRYPTO_MESSAGE_PARAMETER_NO_OVERLAP, "A crypto message was received with a parameter that has no overlap with the local parameter" },
{ QUIC_CRYPTO_MESSAGE_INDEX_NOT_FOUND, "A crypto message was received that contained a parameter with too few values" },
- { QUIC_CRYPTO_INTERNAL_ERROR, "An internal error occured in crypto processing" },
+ { QUIC_CRYPTO_INTERNAL_ERROR, "An internal error occurred in crypto processing" },
{ QUIC_CRYPTO_VERSION_NOT_SUPPORTED, "A crypto handshake message specified an unsupported version" },
{ QUIC_CRYPTO_NO_SUPPORT, "There was no intersection between the crypto primitives supported by the peer and ourselves" },
@@ -631,7 +631,7 @@ enum QuicErrorCode {
values. */
QUIC_CRYPTO_MESSAGE_INDEX_NOT_FOUND = 37,
- /* An internal error occured in crypto processing. */
+ /* An internal error occurred in crypto processing. */
QUIC_CRYPTO_INTERNAL_ERROR = 38,
/* A crypto handshake message specified an unsupported version. */